summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authordolorous <dolorous@c06c8d41-db1a-0410-9941-cceddc491573>2008-04-07 04:52:35 +0000
committerdolorous <dolorous@c06c8d41-db1a-0410-9941-cceddc491573>2008-04-07 04:52:35 +0000
commit149c6fb2d95c12bcd27c067929da23c8a8335f33 (patch)
tree51f6bacb8bd020a1f10300348281017a8ca6a80e
parentb681ad7103cd3bad79138e0817650e92a3dbc0e2 (diff)
downloadcrawl-ref-149c6fb2d95c12bcd27c067929da23c8a8335f33.tar.gz
crawl-ref-149c6fb2d95c12bcd27c067929da23c8a8335f33.zip
For consistency, since Zin's Recite can pacify holy beings, let Ely's
healing have a chance of doing the same. git-svn-id: https://crawl-ref.svn.sourceforge.net/svnroot/crawl-ref/trunk@4090 c06c8d41-db1a-0410-9941-cceddc491573
-rw-r--r--crawl-ref/source/spells1.cc7
1 files changed, 4 insertions, 3 deletions
diff --git a/crawl-ref/source/spells1.cc b/crawl-ref/source/spells1.cc
index 672de08935..4a559dcf8f 100644
--- a/crawl-ref/source/spells1.cc
+++ b/crawl-ref/source/spells1.cc
@@ -597,8 +597,8 @@ static bool _can_pacify_monster(const monsters *mon, const int healed)
if (mons_friendly(mon) || mons_neutral(mon))
return false;
- // Ely only cares about natural monsters
- if (mons_holiness(mon) != MH_NATURAL)
+ // Ely only cares about natural/holy monsters
+ if (mons_holiness(mon) != MH_NATURAL && mons_holiness(mon) != MH_HOLY)
return false;
if (mons_intel(mon->type) <= I_PLANT) // no self-awareness
@@ -608,7 +608,8 @@ static bool _can_pacify_monster(const monsters *mon, const int healed)
return false;
const int factor = (mons_intel(mon->type) <= I_ANIMAL) ? 3 : // animals
- (is_player_same_species(mon->type)) ? 2 // same species
+ (is_player_same_species(mon->type) // same species
+ || mons_holiness(mon) == MH_HOLY) ? 2 // holy beings
: 1; // other
const int random_factor = random2(you.skills[SK_INVOCATIONS] * healed/3);